# ProvenanceInput

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**application_stack** | [**PythonStack**](PythonStack.md) |  |
**justification** | [**Justification**](Justification.md) |  | [optional]
**kebechet_metadata** | [**KebechetMetadata**](KebechetMetadata.md) |  | [optional]
**stack_info** | [**StackInfo**](StackInfo.md) |  | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

